@@ -1225,6 +1225,41 @@ cdrom_setspeed(const char *spec) {
 	}
 }
 
+/*
+ * Check if @node is read-only filesystem by access() or futimens().
+ *
+ * Note that access(2) uses real-UID (= useless for suid programs)
+ * and euidaccess(2) does not check for read-only FS.
+ */
+static int
+is_readonly(const char *node)
+{
+	int res = 0;
+
+	if (getuid() == geteuid()) {
+		if (access(node, W_OK) == -1 && errno == EROFS)
+			res = 1;
+	}
+#ifdef HAVE_FUTIMENS
+	else {
+		struct timespec times[2];
+		int fd = open(node, O_RDONLY);
+
+		if (fd < 0)
+			goto done;
+
+		times[0].tv_nsec = UTIME_NOW;	/* atime */
+		times[1].tv_nsec = UTIME_OMIT;	/* mtime */
+
+		if (futimens(fd, times) == -1 && errno == EROFS)
+			res = 1;
+		close(fd);
+	}
+done:
+#endif
+	return res;
+}
+
 /*
  * try_mount_one()
  *	Try to mount one file system.
@@ -1326,6 +1361,17 @@ mount_retry:
     }
   }
 
+  /* Kernel allows to use MS_RDONLY for bind mounts, but the read-only request
+   * could be silently ignored. Check it to avoid 'ro' in ntab and 'rw' in
+   * /proc/mounts.
+   */
+  if (!fake && mnt5_res == 0 &&
+      (flags & MS_BIND) && (flags & MS_RDONLY) && !is_readonly(node)) {
+
+      printf(_("mount: warning: %s seems to be mounted read-write.\n"), node);
+      flags &= ~MS_RDONLY;
+  }
+
   if (fake || mnt5_res == 0) {
       /* Mount succeeded, report this (if verbose) and write mtab entry.  */
 
@@ -1878,6 +1924,7 @@ static struct option longopts[] = {
 	{ "make-rslave", 0, 0, 141 },
 	{ "make-rprivate", 0, 0, 142 },
 	{ "make-runbindable", 0, 0, 143 },
+	{ "no-canonicalize", 0, 0, 144 },
 	{ "internal-only", 0, 0, 'i' },
 	{ NULL, 0, 0, 0 }
 };
@@ -2170,7 +2217,9 @@ main(int argc, char *argv[]) {
 		case 143:
 			mounttype = (MS_UNBINDABLE | MS_REC);
 			break;
-
+		case 144:
+			nocanonicalize = 1;
+			break;
 		case '?':
 		default:
 			usage (stderr, EX_USAGE);
@@ -2205,12 +2254,19 @@ main(int argc, char *argv[]) {
 		if (((uid_t)0 == ruid) && (ruid == euid)) {
 			restricted = 0;
 		}
-	}
 
-	if (restricted &&
-	    (types || options || readwrite || nomtab || mount_all ||
-	     fake || mounttype || (argc + specseen) != 1)) {
-		die (EX_USAGE, _("mount: only root can do that"));
+		if (restricted &&
+		    (types || options || readwrite || nomtab || mount_all ||
+		     nocanonicalize || fake || mounttype ||
+		     (argc + specseen) != 1)) {
+
+			if (ruid == 0 && euid != 0)
+				/* user is root, but setuid to non-root */
+				die (EX_USAGE, _("mount: only root can do that "
+					"(effective UID is %d)"), euid);
+
+			die (EX_USAGE, _("mount: only root can do that"));
+		}
 	}
 
 	atexit(unlock_mtab);
